yakumo.glance.v2.image_member.Resource

Package yakumo :: Package glance :: Package v2 :: Module image_member :: Class Resource |
[hide private]
[frames] | no frames]

# Class Resource

source code

           object --+
                    |
        base.Resource --+
                        |
    base.GlanceV2Resource --+
                            |
                           Resource

resource class for image members on Image V2 API

Instance Methods | [hide private]
None |
update(self, status=`'``__UNDEF__``'`) Update status of a member | source code
Inherited from `base.Resource`: `__eq__`, `__getattr__`, `__init__`, `__ne__`, `__repr__`, `__str__`, `delete`, `get_attrs`, `get_id`, `reload`, `wait_for_finished` Inherited from `base.Resource` (private): `_clear_attrs`, `_set_attrs` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `base.Resource` (private): `_attrs`, `_id`, `_loaded`, `_stable_state`, `_state_attr`, `_sub_manager_list`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### update(self, status=`'``__UNDEF__``'`) | source code
Update status of a member Parameters: `status` (str) - Member status ('accepted','pending','rejected',or 'all') Returns: None Overrides: base.Resource.update